@@ -2,6 +2,7 @@ from pymongo.database import Database
 from typing import TypedDict, List
 import datetime as dt
 
+
 class CBOEDocument(TypedDict):
     option: str
     bid: float
@@ -27,12 +28,14 @@ class CBOEDocument(TypedDict):
     percent_change: float
     prev_day_close: float
 
+
 class CBOEQueries:
-    def __init__(self, db: Database):
+    def __init__(self, db: Database, collection_name: str):
+        self.collection_name = collection_name
         self.collection = db["radar-cboe"]
-    
+
     def insert_many(self, documents: List[CBOEDocument]):
         row_date = dt.datetime.now(dt.timezone.utc)
         for i in range(len(documents)):
             documents[i]["row_date"] = row_date
-        return self.collection.insert_many(documents)
\ No newline at end of file
+        return self.collection.insert_many(documents)
